@@ -174,11 +174,18 @@ class GtkItemFactory(GtkObject):
 	parse_rc = _gtk.gtk_item_factory_parse_rc
 	parse_rc_string = _gtk.gtk_item_factory_parse_rc_string
 	def get_widget(self, path):
-		return _obj2inst(_gtk.gtk_item_factory_get_widget(self._o,
-								  path))
+		ret = _gtk.gtk_item_factory_get_widget(self._o, path)
+		if ret:
+			return _obj2inst(ret)
+		else:
+			return ret
 	def get_widget_by_action(self, action):
-		return _obj2inst(_gtk.gtk_item_factory_get_widget_by_action(
-			self._o, action))
+		ret = _gtk.gtk_item_factory_get_widget_by_action(self._o,
+								 action)
+		if ret:
+			return _obj2inst(ret)
+		else:
+			return ret
 	class __wrap_cb:
 		def __init__(self, cb):
 			self.cb = cb
@@ -249,6 +256,8 @@ class GtkWidget(GtkObject):
 					       hot_x, hot_y)
 	def drag_get_source_widget(self, context):
 		return _obj2inst(_gtk.gtk_drag_get_source_widget(context))
+	def drag_status(self, context, action, time):
+		_gtk.gdk_drag_status(context, action, time)
 	def draw(self, rect):
 		_gtk.gtk_widget_draw(self._o, rect)
 	def draw_default(self, obj=None):
@@ -263,6 +272,8 @@ class GtkWidget(GtkObject):
 		_gtk.gtk_widget_lock_accelerators(self._o)
 	def get_ancestor(self, type):
 		return _obj2inst(_gtk.gtk_widget_get_ancestor(self._o, type))
+	def get_colormap(self):
+		return _gtk.gtk_widget_get_colormap(self._o)
 	def get_composite_name(self):
 		return _gtk.gtk_widget_get_composite_name(self._o)
 	def get_events(self):
@@ -521,8 +532,10 @@ class GtkToggleButton(GtkButton):
 	    raise AttributeError, attr
 	def set_mode(self, di):
 		_gtk.gtk_toggle_button_set_mode(self._o, di)
-	def set_state(self, state):
-		_gtk.gtk_toggle_button_set_state(self._o, state)
+	def set_active(self, active):
+		_gtk.gtk_toggle_button_set_active(self._o, active)
+	def get_active(self):
+		return _gtk.gtk_toggle_button_get_active(self._o)
 	def toggled(self, obj):
 		_gtk.gtk_toggle_button_toggled(self._o)
 
@@ -611,7 +624,7 @@ class GtkMenuItem(GtkItem):
 	def set_placement(self, placement):
 		_gtk.gtk_menu_item_set_placement(self._o, placement)
 	def configure(self, show_toggle, show_sub):
-		_gtk.gtk_menu_item_configure(self._o, show_toggle. show_sub)
+		_gtk.gtk_menu_item_configure(self._o, show_toggle, show_sub)
 	def select(self, obj=None):
 		_gtk.gtk_menu_item_select(self._o)
 	def deselect(self, obj=None):
@@ -640,8 +653,8 @@ class GtkCheckMenuItem(GtkMenuItem):
 		raise AttributeError, attr
 	def set_show_toggle(self, always):
 		_gtk.gtk_check_menu_item_set_show_toggle(self._o, always)
-	def set_state(self, state):
-		_gtk.gtk_check_menu_item_set_state(self._o, state)
+	def set_active(self, active):
+		_gtk.gtk_check_menu_item_set_active(self._o, active)
 	def toggled(self, obj=None):
 		_gtk.gtk_check_menu_item_toggled(self._o)
 
@@ -819,8 +832,8 @@ class GtkFileSelection(GtkWindow):
 		_gtk.gtk_file_selection_set_filename(self._o, filename)
 	def get_filename(self):
 		return _gtk.gtk_file_selection_get_filename(self._o)
-	def complete(self):
-		_gtk.gtk_file_selection_complete(self._o)
+	def complete(self, pattern):
+		_gtk.gtk_file_selection_complete(self._o, pattern)
 	def show_fileop_buttons(self):
 		_gtk.gtk_file_selection_show_fileop_buttons(self._o)
 	def hide_fileop_buttons(self):
@@ -1051,6 +1064,7 @@ class GtkCList(GtkContainer):
 	def __getattr__(self, attr):
 		attrs = {
 			'selection':_gtk.gtk_clist_get_selection,
+			'focus_row':_gtk.gtk_clist_get_focus_row,
 		}
 		if attrs.has_key(attr):
 			return attrs[attr](self._o)
@@ -1211,6 +1225,14 @@ class GtkCTree(GtkCList):
 			self._o = _gtk.gtk_ctree_new_with_titles(cols,
 								 tree_col,
 								 titles)
+	def __getattr__(self, attr):
+		attrs = {
+			'selection':_gtk.gtk_ctree_get_selection,
+		}
+		if attrs.has_key(attr):
+			return attrs[attr](self._o)
+		else:
+			return GtkCList.__getattr__(self, attr)
 	def base_nodes(self):
 		# this returns a list of the base nodes.  Useful for recursion
 		return _gtk.gtk_ctree_base_nodes(self._o)
@@ -1492,6 +1514,8 @@ class GtkMenu(GtkMenuShell):
 		_gtk.gtk_menu_set_accel_group(self._o, group._ag)
 	def set_tearoff_state(self, torn_off):
 		_gtk.gtk_menu_set_tearoff_state(self._o, torn_off)
+	def set_title(self, title):
+		_gtk.gtk_menu_set_title(self._o, title)
 
 class GtkNotebook(GtkContainer):
 	get_type = _gtk.gtk_notebook_get_type
@@ -1610,8 +1634,9 @@ class GtkPacker(GtkContainer):
 	def add_defaults(self, child, side, anchor, options):
 		_gtk.gtk_packer_add_defaults(self._o, child._o, side, anchor,
 					     options)
-	def add(self, child, side, anchor, options, border_width, pad_x,
-		pad_y, i_pad_x, i_pad_y):
+	def add(self, child, side=SIDE_TOP, anchor=ANCHOR_CENTER,
+		options=0, border_width=0, pad_x=0, pad_y=0,
+		 i_pad_x=0, i_pad_y=0):
 		_gtk.gtk_packer_add(self._o, child._o, side, anchor, options,
 				    border_width, pad_x, pad_y, i_pad_x,
 				    i_pad_y)
@@ -1671,7 +1696,7 @@ class GtkVPaned(GtkPaned):
 		if _obj: self._o = _obj; return
 		self._o = _gtk.gtk_vpaned_new()
 
-class GtkScrolledWindow(GtkContainer):
+class GtkScrolledWindow(GtkBin):
 	get_type = _gtk.gtk_scrolled_window_get_type
 	def __init__(self, hadj=None, vadj=None, _obj=None):
 		if _obj: self._o = _obj; return
@@ -1964,6 +1989,8 @@ class GtkSpinButton(GtkEntry):
 		_gtk.gtk_spin_button_set_shadow_type(self._o, shadow_type)
 	def set_snap_to_ticks(self, snap):
 		_gtk.gtk_spin_button_set_snap_to_ticks(self._o, snap)
+	def update(self):
+		_gtk.gtk_spin_button_update(self._o)
 
 class GtkText(GtkEditable):
 	get_type = _gtk.gtk_text_get_type
@@ -2138,7 +2165,7 @@ class GtkProgress(GtkWidget):
 		print "reconfigure deprecated -- use configure"
 		self.configure(value, min, max)
 	def configure(self, value, min, max):
-		_gtk.gtk_progress_reconfigure(self._o, value, min, max)
+		_gtk.gtk_progress_configure(self._o, value, min, max)
 	def set_percentage(self, pcnt):
 		_gtk.gtk_progress_set_percentage(self._o, pcnt)
 	def set_value(self, value):
@@ -2152,7 +2179,7 @@ class GtkProgress(GtkWidget):
 	def get_text_from_value(self, value):
 		return _gtk.gtk_progress_get_text_from_value(self._o, value)
 	def get_current_percentage(self):
-		return _gtk.gtk_progress_get_percentage(self._o)
+		return _gtk.gtk_progress_get_current_percentage(self._o)
 	def get_percentage_from_value(self, value):
 		return _gtk.gtk_progress_get_percentage_from_value(self._o,
 								   value)
@@ -2462,17 +2489,31 @@ def atom_name(atom):
 	return _gtk.gdk_atom_name(atom)
 
 # pixmap loading
-def create_pixmap_from_xpm(window, bg, xpm):
-	if hasattr(window, '_o'):
-		window.realize()
-		window = window.get_window()
-	return _gtk.gdk_pixmap_create_from_xpm(window, bg, xpm)
+def create_pixmap_from_xpm(object, bg, xpm):
+	if type(object) == _gtk.GdkWindowType:
+		return _gtk.gdk_pixmap_create_from_xpm(object, bg, xpm)
+	else:
+		if hasattr(object, 'get_colormap'):
+			cmap = object.get_colormap()
+		elif hasattr(object, 'colormap'):
+			cmap = object.colormap
+		else:
+			cmap = object
+		return _gtk.gdk_pixmap_colormap_create_from_xpm(None, cmap,
+								bg, xpm)
 # use XPM data ...
-def create_pixmap_from_xpm_d(window, bg, xpm_d):
-	if hasattr(window, '_o'):
-		window.realize()
-		window = window.get_window()
-	return _gtk.gdk_pixmap_create_from_xpm_d(window, bg, xpm_d)
+def create_pixmap_from_xpm_d(object, bg, xpm_d):
+	if type(object) == _gtk.GdkWindowType:
+		return _gtk.gdk_pixmap_create_from_xpm_d(object, bg, xpm_d)
+	else:
+		if hasattr(object, 'get_colormap'):
+			cmap = object.get_colormap()
+		elif hasattr(object, 'colormap'):
+			cmap = object.colormap
+		else:
+			cmap = object
+		return _gtk.gdk_pixmap_colormap_create_from_xpm_d(None, cmap,
+								  bg, xpm_d)
 def create_pixmap(window, width, height, depth=-1):
 	if (hasattr(window, '_o')):
 	        window.realize()
@@ -2506,3 +2547,14 @@ def draw_segments(drawable, gc, segs):
 def draw_lines(drawable, gc, points):
 	_gtk.gdk_draw_lines(drawable, gc, points)
 
+
+# screen size
+def screen_width():
+	return _gtk.gdk_screen_width()
+def screen_height():
+	return _gtk.gdk_screen_height()
+
+def screen_width_mm():
+	return _gtk.gdk_screen_width_mm()
+def screen_height_mm():
+	return _gtk.gdk_screen_height_mm()
